all.Enfss<-function(){
     cat("\n")
     note_for_Enfss_input()
     cat("\n")
     note_for_close_window()
     EnfSSpar<-data.frame(parameter=c("Gender","bw (kg)","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     EnfSSpar<-edit(EnfSSpar)
##     EnfSSpar<-ycheck(EnfSSpar)
     cat("\n")
     Enf.ss(EnfSSpar[6,2],EnfSSpar[4,2],EnfSSpar[5,2],EnfSSpar[3,2],EnfSSpar[2,2],EnfSSpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Enfss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-pocpr(samplesStats("ka"),EnfSSpar[3,2],EnfSSpar[4,2],EnfSSpar[5,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-pocpr(samplesStats("ka"),EnfSSpar[3,2],EnfSSpar[4,2],EnfSSpar[4,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n")  
     Enf.more()
}